@@ -60,8 +60,8 @@ c     **************
       integer sum1, i, sum2,  levelmx
 
       call epfixConfig
+      call epMemoCnfgFile   ! next one is here bef. 9.15
       call epReadConfig
-      call epMemoCnfgFile
       sellist = ' '
       call epsetDflt     ! set default parameters
       call epsetDflt2
@@ -483,11 +483,11 @@ c     *  'Note: daughters and mothers are both drawn. ', 1)
       if(containmode .eq. 1) then
          call cerrorMsg(
      *   'Enter daughter comp. numbers to'//
-     *     ' display their mothers (with / )', 1)
+     *     ' display their mothers (with / last )', 1)
       else
          call cerrorMsg(
      *   'Enter mother comp. numbers to'//
-     *   ' display their daughters (with / )', 1)
+     *   ' display their daughters (with / last )', 1)
       endif
 
       do i = 1,  maxspecifiable
@@ -657,18 +657,26 @@ c     ********************
       record /Component/ cmp(*)
 
 c               show Matreska component
-      integer i, k, j, lc
+      integer i, k, j, lc, ll, m
 
       do i = 1, (NumComp - NumWorld)
          k = cmp(i).NMatreska 
          if( k .gt. 0) then
-            write(msg,'(" #",i5," contains" 200i5)') i,
-c(((((((((((((
-c     *      (cmp(i).ContainsR(j),j=1, k)
-     *      (CnArea( cmp(i).ContainsR+j ),j=1, k)
-c))))))))))))))
+            ll = min(10, k)
+            write(msg,
+     *     '(" #",i7," contains " 10i7)') i,
+     *      (CnArea( cmp(i).ContainsR+j ),j=1, ll)
             call  ksupblank(msg, lc)
             call cerrorMsg(msg, 1)
+            if(k > 10) then
+               do m = 11, k, 10
+                  write(msg, 
+     *            '("     " 10i7)') 
+     *            (CnArea( cmp(i).ContainsR+j ),j=m, min((m+9), k))
+                  call  ksupblank(msg, lc)
+                  call cerrorMsg(msg, 1)
+               enddo
+            endif
          endif
       enddo
       end
@@ -686,7 +694,7 @@ c            show components which are contained by others
          k = cmp(i).NContainer
          if( k .gt. 0) then
             write(msg,
-     *      '(" #",i5," is contained by " i5," component(s)")') i,
+     *      '(" #",i7," is contained by " i7," component(s)")') i,
      *      k
             call  ksupblank(msg,  lc)
             call cerrorMsg(msg, 1)
@@ -1267,6 +1275,7 @@ c         space is not drawn by default.
 
       subroutine epsetDflt2
       implicit none
+#include "ZepMaxdef.h"
 #include "ZepDraw.h"
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
@@ -1281,11 +1290,18 @@ c         make structure table
             endif
          enddo
          nstruc = nstruc + 1
+         if( nstruc > maxNewStruc ) then
+            write(0,*) ' # of new structure > ', maxNewStruc
+            write(0,*) ' Enlarge MAX_NEW_STRUC in ZepMaxdef.h'
+            stop
+         endif
          strucarray(nstruc) =Det.cmp(i).struc
+         write(0,*) nstruc,  strucarray(nstruc)
  10      continue
       enddo
       write(struclist, '(40a)')
      *   (strucarray(i)(1:klena(strucarray(i)))//' ', i=1,nstruc)
+
       NumComp = Det.nct
       NumWorld = Det.nworld
       end
@@ -1456,9 +1472,10 @@ c    *********************
 
       tempfile = configFile
       do while (icon .ne. 0)
-         msg ="Enter config file path(e.g,  "//
-     *        configFile(1:klena(configFile))//" )"
-         call cerrorMsg(msg, 1)
+         write(0,'(a)')
+     *   "Enter config file path: default is ",
+     *   trim(configFile),
+     *   "If above is OK, simply push Enter"
          read(*, '(a)',  iostat=ios) configFile
          if(configFile .eq. ' ') then
             configFile = tempfile
@@ -1524,6 +1541,10 @@ c         read config file
       enddo
 c      call mediaCount(Det.cmp, matdef, noOfMedia, compnToMn)
       call mediaCount(Det.cmp, Det.nct, matdef, noOfMedia)
+      write(0,*) 'no of comps for each media'
+      do i = 1, noOfMedia
+         write(0,'(a,1x,i6)') matdef(i), NoOfCompsEachMedia(i)
+      enddo
       end
       subroutine epMemoCnfgFile
 c          memorize current config file name in Work/.configrc
