@@ -23,8 +23,8 @@
       include "ZdEdxSpec.h"  ! for epUrban. smarter solution will be using
                             !   module dEdxNone
 !       MeV unit electron mass.
-       type(epmedia):: media         ! input. 
-       type(ptcl):: aPtcl        ! input. a particle
+      record /epmedia/media         ! input. 
+      record /ptcl/aPtcl        ! input. a particle
 
       real*8 dedt      ! output. restricted Energy loss rate.   GeV / (g/cm2). 
       real*8 dedtfull  ! output full dE/dx
@@ -53,8 +53,8 @@
 
 !
 !               energy in MeV unit
-      E = aPtcl%fm%p(4)*1000.
-      mass= aPtcl%mass*1000.
+      E = aPtcl.fm.p(4)*1000.
+      mass= aPtcl.mass*1000.
       g = E/mass
       truebeta2 = 1. -(1.0d0/g)**2
       if(truebeta2 .lt. bbbeta2) then
@@ -80,9 +80,9 @@
 !           sh.a/Beta2( sh.b +ln(2*g^2b^2wm/m) -2Beta^2 -delta
 !                 +spin_term )
 ! 
-      full = media%sh%b +  log(2*u*gb2) -2.0*Beta2 
+      full = media.sh.b +  log(2*u*gb2) -2.0*Beta2 
 !            assume spin 0 particle is only pi, K
-      if(aPtcl%code .ne. kpion .and. aPtcl%code .ne. kkaon) then
+      if(aPtcl.code .ne. kpion .and. aPtcl.code .ne. kkaon) then
 !          spin 1/2 term; (almost negligible)
          full = full +  (wm/E)**2/4.
       endif
@@ -94,16 +94,16 @@
 !                assuming sh.a/Beta2 = sh.a at E>5GeV
 !                compute effect without sh.a and add later to full
 !            pi,K,p, scales as E*sqrt(mu/M)
-!     see if restricted energy is requested
-      if(wm .gt. media%sh%w0) then
+!             see if restricted energy is requested
+      if(wm .gt. media.sh.w0) then
 !             yes. requested
 !                subtract average loss rate from  Ek>w0 region
 !                loss for Ek>w0
-         integ = log(wm/media%sh%w0) - Beta2*(1.0-media%sh%w0/wm)
+         integ = log(wm/media.sh.w0) - Beta2*(1.0-media.sh.w0/wm)
 !            assume spin 0 particle is only pi, K
-         if(aPtcl%code .ne. kpion .and. aPtcl%code .ne. kkaon) then
+         if(aPtcl.code .ne. kpion .and. aPtcl.code .ne. kkaon) then
 !               mu, p, etc. spin = 1/2
-            integ = integ + ((wm/E)**2-(media%sh%w0/E)**2)/4
+            integ = integ + ((wm/E)**2-(media.sh.w0/E)**2)/4
          endif
       else
          integ = 0.
@@ -113,8 +113,8 @@
       F =  integ 
       restricted = full - F
 
-      dedt = media%sh%a/Beta2*restricted  
-      full = full*  media%sh%a/Beta2
+      dedt = media.sh.a/Beta2*restricted  
+      full = full*  media.sh.a/Beta2
 
       if(truebeta2 .lt. bbbeta2) then
          cF  = ( a* logbbbeta - b )*logbbbeta
@@ -147,13 +147,12 @@
          endif
       endif
 !         x  Z**2 and to GeV unit
-      dedt=dedt * aPtcl%charge**2 * 1.d-3
-      dedtfull = full * aPtcl%charge**2 * 1.d-3
+      dedt=dedt * aPtcl.charge**2 * 1.d-3
+      dedtfull = full * aPtcl.charge**2 * 1.d-3
       end
       subroutine epdedxTargetBrems(media, aPtcl, dedt, dedtfull )
 !           for mu, pi, K, p.  compute dE/dx due to brems by atomic
-!     electrons in the medium.
-!     must be called after epdedxNone
+!      electrons in the medium.
 ! 
       use dEdxNone
       implicit none
@@ -162,8 +161,8 @@
 #include "Zptcl.h"
 #include "Zmass.h"
 #include "ZepTrackp.h"
-       type(epmedia):: media         ! input. 
-       type(ptcl):: aPtcl        ! input. a particle
+      record /epmedia/media         ! input. 
+      record /ptcl/aPtcl        ! input. a particle
       real*8 dedt      ! output. restricted Energy loss rate.   GeV / (g/cm2). 
       real*8 dedtfull  ! output full dE/dx
 
@@ -186,11 +185,11 @@
 !               energy in MeV unit
 
 !          first compute full average dE/dx
-      if( aPtcl%code == kmuon ) then
+      if( aPtcl.code == kmuon ) then
          Incatomicbrems = E > 5000.0 .and. 
      *          btest(TargetElecBrems, 0) 
       elseif(  btest(TargetElecBrems, 1) ) then
-         Incatomicbrems = E*sqrt(masmu/aPtcl%mass) > 5000.
+         Incatomicbrems = E*sqrt(masmu/aPtcl.mass) > 5000.
       else
          Incatomicbrems = .false.
       endif
@@ -202,12 +201,12 @@
          atomicEbrem = 0.
       endif
 !             see if restricted energy is requested
-      if(wm .gt. media%sh%w0) then
+      if(wm .gt. media.sh.w0) then
 !             yes. requested
          if( Incatomicbrems ) then
 !                 Integ(0~wm) =Integ(0~w0) + Integ(w0~wm)
 !             so  Integ(w0~wm) = Ineg(0~wm)-Integ(0~w0)
-            temp = log(2*media%sh%w0/emass)
+            temp = log(2*media.sh.w0/emass)
             atomicEbremCut = atomicEbrem-
      *          0.00116*(log(2*g)-0.3333*temp)*temp*temp
          else
@@ -219,11 +218,11 @@
       full =  atomicEbrem
       restricted = full -  atomicEbremCut
 
-      dedt = media%sh%a*restricted  
-      full = full*  media%sh%a
+      dedt = media.sh.a*restricted  
+      full = full*  media.sh.a
 !         x  Z**2 and to GeV unit, though Z=1 normally
-      dedt=dedt * aPtcl%charge**2 * 1.d-3
-      dedtfull = full * aPtcl%charge**2 * 1.d-3
+      dedt=dedt * aPtcl.charge**2 * 1.d-3
+      dedtfull = full * aPtcl.charge**2 * 1.d-3
       end
 !     *********************
 !        For the organic and most scintillator, the energy loss by
@@ -236,7 +235,7 @@
 !         called only if quenching terms are given in media data
 !        or modifier is specified 
       subroutine epOrgCorrec(modi, media, aPtcl, dedx, cf)
-#if defined (Solaris) || (jaxa) || (jaxaflat)
+#if defined (Solaris)
       use epModify,idmodiy=>id
 #else 
       use epModify
@@ -248,8 +247,8 @@
 #include "Zmass.h"
       integer,intent(in):: modi ! modifier index of the component
                  ! where current ptcl is.
-       type(epmedia)::  media  ! input.
-       type(ptcl)::  aPtcl   ! input.
+      record /epmedia/ media  ! input.
+      record /ptcl/ aPtcl   ! input.
       real*8  dedx   ! input.  dE/dx (GeV/(g/cm^2) for the partcle
       real*8  cf     ! output. correction factor. dE_eff = cf x dE_true
       character*1 id
@@ -274,7 +273,7 @@
       endif
       end
       subroutine epQuenchCoeff(modi, media, aPtcl, dedx, a,b,c,id)
-#if defined (Solaris) || (jaxa) || (jaxaflat)  
+#if defined (Solaris)
       use epModify,idmodiy=>id
 #else 
       use epModify
@@ -285,8 +284,8 @@
 #include "Zmass.h"
       integer,intent(in):: modi ! modifier index of the component
                  ! where current ptcl is.
-       type(epmedia)::  media  ! input.
-       type(ptcl)::  aPtcl   ! input. see next
+      record /epmedia/ media  ! input.
+      record /ptcl/ aPtcl   ! input. see next
       real*8  dedx   ! input.  dE/dx (GeV/(g/cm^2) for the partcle
                !  these two are not yet used. 
                ! a,b,c may be dependent on these.
@@ -296,8 +295,8 @@
 
       if( modi > 0 ) then
          if( modi > maxModifyNum) then
-            write(0,*) 'modifier =', modi, 'for media =',media%name
-            write(0,*) ' > ', maxModifyNum, ' i%e. max # in ModifyFile'
+            write(0,*) 'modifier =', modi, 'for media =',media.name
+            write(0,*) ' > ', maxModifyNum, ' i.e. max # in ModifyFile'
             write(0,*) 'To run prg., correct data or give blank '
             write(0,*) ' to ModifyFile in epicsfile'
             stop
@@ -326,13 +325,13 @@
                write(0,*) ' ModifyFile index =', modi
                stop 2222
             endif
-         elseif( media%Birks /= ' ') then  ! not nec. Birks
+         elseif( media.Birks /= ' ') then  ! not nec. Birks
             call epdefaultQuenchCoef(media, a,b,c,id)
          else
             id = "n"
          endif
       else
-         if( media%Birks /= ' ') then
+         if( media.Birks /= ' ') then
             call epdefaultQuenchCoef(media,  a,b,c,id)
          else
             id = "n"
@@ -342,13 +341,13 @@
       subroutine epdefaultQuenchCoef(media, a,b,c,id)
       implicit none
 #include "Zmedia.h"
-       type(epmedia)::  media  ! input.
+      record /epmedia/ media  ! input.
       real(8),intent(out)::a,b,c  !   quench coef.
       character(1),intent(out)::id !one of T,B,L,n for Talre, Birks, LOg
              ! n is for no quenching
 !             use defualt for this media
-      a = media%BirksC1
-      if( media%Birks == "B" ) then 
+      a = media.BirksC1
+      if( media.Birks == "B" ) then 
 !            Birks formula without Chou's 2nd term(c2) or heavy correction
 !            term(cc )
 !      if( abs( aPtcl.charge ) .gt. 1)  then
@@ -358,17 +357,17 @@
 !        at present, we don't use above two factors
 ! 
          id = "B"
-      elseif(media%Birks == "T" ) then 
-         b = media%BirksC2
+      elseif(media.Birks == "T" ) then 
+         b = media.BirksC2
 !               Tarle's formla 
          id = "T"
-      elseif( media%Birks == "L" ) then 
+      elseif( media.Birks == "L" ) then 
 !                typcal values c1,c2,cc; 23.53 0.0868 4.611
-         b = media%BirksC2
-         c = media%BirksCC
+         b = media.BirksC2
+         c = media.BirksCC
          id ="L"
       else
-         write(0,*) ' media%Birks =', media%Birks, ' undef'
+         write(0,*) ' media.Birks =', media.Birks, ' undef'
          stop 1111
       endif
       end
