@@ -1,10 +1,10 @@
-!     ****************************************************************
-!     *                                                              *
-!     * dpdedxe:  gives -de/dx  (gev/(g/cm2) of   e-/e+
-!     *                                                              *
-!     Restricted energy loss rate dE/dt 
-!         Full -  moller or bhabha loss(>RecoilkEmin)
-!
+c     ****************************************************************
+c     *                                                              *
+c     * dpdedxe:  gives -de/dx  (gev/(g/cm2) of   e-/e+
+c     *                                                              *
+c     Restricted energy loss rate dE/dt 
+c         Full -  moller or bhabha loss(>RecoilkEmin)
+c
       subroutine epdedxe(media,  aPtcl, dedt, dedtfull)
       implicit none
 #include "Zmedia.h"
@@ -13,14 +13,14 @@
 
 	include "ZdEdxSpec.h"
 
-       type(epmedia):: media    !  input. media
-       type(ptcl)::  aPtcl  !  input. a Particle (e- or e+) 
+      record /epmedia/media    !  input. media
+      record /ptcl/ aPtcl  !  input. a Particle (e- or e+) 
       real*8  dedt ! output.  restricted dE/dt GeV/(g/cm^2) 
       real*8  dedtfull ! output  full dE/dt //
 
       real*8 emass
       real*8 E, gi, Beta2, x, cb
-!      real*8 dltx, wm, wlg, g, D, u, F, y
+c      real*8 dltx, wm, wlg, g, D, u, F, y
       real*8 dltx, g, D, u, F, y
 
       real*8 delta
@@ -40,18 +40,18 @@
      *           loglindbeta = -4.605170186E+00)
       parameter (a = (1.+gra)/2.d0/(logbbbeta-loglindbeta),
      *           b = 2*a*loglindbeta + 1.) 
-!
+c
 
       parameter (emass = masele*1000.d0)   ! in MeV
 
-!       Energy, mass=emass  in MeV unit
-      E = aPtcl%fm%p(4)*1000.d0
+c       Energy, mass=emass  in MeV unit
+      E = aPtcl.fm.p(4)*1000.d0
       g = E/emass
       gi= 1.d0/g
       truebeta2= 1. - gi**2
       if(truebeta2 .lt. bbbeta2) then
          Beta2 = bbbeta2
-!         wm = emass*Beta2/2
+c         wm = emass*Beta2/2
          g = (1.+Beta2/2)
          E = emass*g
       else
@@ -59,45 +59,45 @@
       endif
       g1 =g + 1.0
       u = g - 1.0  ! incident kinetic energy in Me unit
-!       x=log10(p/mc)
-!      x=log10( (E/emass)**2 - 1. ) / 2  ! = log10(gbeta) = 0.4343log(gbeta)
+c       x=log10(p/mc)
+c      x=log10( (E/emass)**2 - 1. ) / 2  ! = log10(gbeta) = 0.4343log(gbeta)
       x=log10( g**2 - 1. ) / 2  ! = log10(gbeta) = 0.4343log(gbeta)
-!        from v8.80, dltx is not used but usual delta is used.
+c        from v8.80, dltx is not used but usual delta is used.
 
-!       dE/dx = sh.a/Beta2* (B0 +sh.b -delta +other)
-!             other=shell correction < 0.75 % effect at samll E
-!
-!         We get restricted dE/dx; i.e knock-on K.E<sh.w0
-!        First get full dE/dx and subtract dE/dx (>sh.w0)
-!      (get B0 + sh.b  part)
+c       dE/dx = sh.a/Beta2* (B0 +sh.b -delta +other)
+c             other=shell correction < 0.75 % effect at samll E
+c
+c         We get restricted dE/dx; i.e knock-on K.E<sh.w0
+c        First get full dE/dx and subtract dE/dx (>sh.w0)
+c      (get B0 + sh.b  part)
 
-      RKEmin = media%sh%w0/emass
-      if(aPtcl%charge .eq. -1) then
-!          electron; max recoil kinetic E
+      RKEmin = media.sh.w0/emass
+      if(aPtcl.charge .eq. -1) then
+c          electron; max recoil kinetic E
          tm = min(u/2, RKEmin)
 
-         full = media%sh%b + log(u**2*g1/2) +
+         full = media.sh.b + log(u**2*g1/2) +
      *             (1.0+u**2/8. -(u+g)*ln2)/g/g
 
          if(u/2 .gt. RKEmin) then
-!             possible  max recoil > w0; need subtraction 
+c             possible  max recoil > w0; need subtraction 
             vc = RKEmin/u
-!               loss in w0~tm; integrate Moller 
+c               loss in w0~tm; integrate Moller 
             F = log(0.5/vc)
      *       - (u+g)*gi*gi*(0.5-vc) + (1.-vc/(1.0-vc))
      *        +  0.5*(u*gi)**2 * (0.25-vc**2)
      *       - log(2*(1.-vc)) *(1.+(u+g)*gi*gi)
-!                next is wrong
-!     *       - (u+g)*gi*(0.5-vc) + (1.-vc/(1.0-vc))  
-!     *       + (u*gi)**2* (-log(2*(1.-vc)) +  0.5*(0.25-vc**2))
+c                next is wrong
+c     *       - (u+g)*gi*(0.5-vc) + (1.-vc/(1.0-vc))  
+c     *       + (u*gi)**2* (-log(2*(1.-vc)) +  0.5*(0.25-vc**2))
          else
             F =0. 
          endif
-      elseif(aPtcl%charge .eq. 1) then
-!         positron
+      elseif(aPtcl.charge .eq. 1) then
+c         positron
          tm = min(u, RKEmin)
          vc = RKEmin/u
-         full =  media%sh%b  +   log(u**2*g1/2) + tln2 -
+         full =  media.sh.b  +   log(u**2*g1/2) + tln2 -
      *   Beta2/12. * (((4./g1 + 10.)/g1 + 14.0)/g1 + 23.)
          if(u .gt. RKEmin) then
             y = 1.d0/g1
@@ -112,19 +112,19 @@
             F = 0.
          endif
       else
-         write(0,*) ' charge is invalid for epdedxe=', aPtcl%charge
-         write(0,*) ' ptcl code =', aPtcl%code, aPtcl%subcode
+         write(0,*) ' charge is invalid for epdedxe=', aPtcl.charge
+         write(0,*) ' ptcl code =', aPtcl.code, aPtcl.subcode
          stop
       endif
 
       Tupper = tm*emass/1000.0  ! in GeV; used in Urban
-!       get delta
+c       get delta
       call epdEdxDenC(media, g, delta)
       full = full - delta
       restricted = full - F
-      dedt =media%sh%a/Beta2 *restricted
+      dedt =media.sh.a/Beta2 *restricted
 !  ***********
-      full = full * media%sh%a/Beta2
+      full = full * media.sh.a/Beta2
 !  ***********
 
       if(truebeta2 .lt. bbbeta2) then
@@ -155,7 +155,7 @@
             endif
          endif
       endif
-!          convert it to gev/(g/cm2)
+c          convert it to gev/(g/cm2)
       dedt = dedt *1.d-3
       dedtfull = full * 1.d-3
       end
