@@ -1,4 +1,4 @@
-!  collection of sub/ for init and ending of
+!  correction of sub/ for init and ending of
 !   one event, all event  
 
 !  init for 1 event generation
@@ -9,14 +9,13 @@ subroutine epLighti1ev
   use modepLight
   use modepLightPty
   use modepLightCounter
-  use modepLightUI
   implicit none
   integer::i
 
   do i = 1, LightCompNo
      if( allocated( sensor(i)%pe ) ) then
         deallocate(sensor(i)%pe )
-        deallocate(sensor(i)%pet )
+!        deallocate(sensor(i)%pet )
      endif
      if( allocated( exiting(i)%pc ) ) then
         deallocate( exiting(i)%pc )
@@ -30,9 +29,6 @@ subroutine epLighti1ev
 !        deallocate( lightcomp(i)%dE )
 !     endif
   enddo
-
-  ElossT(:) = 0.
-  ElossE(:) = 0.
 !          weight counter 
   sumni = 0.
   sumniwi = 0.
@@ -68,7 +64,7 @@ subroutine epLighte1ev
 !           elseif( .not. allocated( sensor(i)%pe )) then
         if( .not. allocated( sensor(i)%pe )) then
            allocate( sensor(i)%pe(1:5))
-           allocate( sensor(i)%pet )
+!           allocate( sensor(i)%pet )
            sensor(i)%pe(:) = 0.
         endif
 !           lightcomp(i)%dE = lightcomp(i)%dE * 1.e9   ! in eV
@@ -119,7 +115,7 @@ subroutine epqLightSensor(cn, edepo,  ing,  total, icon )
   use modepLightPty
   use modepLightCounter
   implicit none
-  integer, intent(in):: cn  ! component number of the sensor
+  integer, intent(in):: cn  ! component number of the sensor ( PWO etc )
   real(4), intent(out):: edepo  ! total energy deposit  in the component (GeV)
                  ! has meaning if  (B,mn > 0). else 0. 
   real(4), intent(out):: ing(5) ! p.e by scinti, Ceren, syc, tran, hit
