@@ -1,3 +1,8 @@
+!       honeycomb: when definining this, you have to
+!       give a tight bounding box (world) expressed by
+!       x,y,z range of
+!       (Xs, Xs+a), (Ys,Ys+b), (0, h)
+!
       module honeycomb
       integer,save::Compnum=-1000
       real(8),save::LL, LI, LS, h, W, Xs, a, Ys, b
@@ -169,24 +174,24 @@
 #include "Zglobalc.h"
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
-!
-!
-       type(Component)::  comp  ! output. to recieve the config data.
+c
+c
+       record /Component/ comp  ! output. to recieve the config data.
 
 
-!           9 volume attributes and the direction cosines
-!           (1~6)
-!
-!             next is mandatory
+c           9 volume attributes and the direction cosines
+c           (1~6)
+c
+c             next is mandatory
         call eprpst(comp, 9, 9, 1, 6)
-!
+c
         call  ep_honeycmCnst(comp)
 
         if(LI  <= 0. .or. LS <= 0 .or.  h <= 0. .or.
      *     W<=0. .or. Xs >= Sx+offx
      *    .or.  Xs < 0. .or. Ys < 0   ) then
            write(0, *)
-     *      comp%cn, '-th component: some of LL=', LL,
+     *      comp.cn, '-th component: some of LL=', LL,
      *    ' LI=',LI, ' LS=',LS, ' h=',h,
      *    ' W=', W,  ' Xs=',Xs, ' Ys=',Ys,
      *    ' for honeycomb  invalid'
@@ -194,12 +199,12 @@
         endif
         if( a <= 0 .or. b <= 0. ) then
            write(0, *)
-     *      comp%cn, '-th component: some of a=', a,
+     *      comp.cn, '-th component: some of a=', a,
      *    ' b=', b, ' for honeycomb  invalid'
            stop 98766
         endif
        end subroutine eprhoneycomb
-!   ***************************************
+c   ***************************************
       subroutine epbhoneycomb(comp, pos, dir, length, icon)
       use honeycomb
       implicit none
@@ -211,19 +216,19 @@
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-!
-!    find length to the boundary of a honeycomb specfied by 
-!    'comp' from 'pos' with direction cos 'dir'
-!    'pos' and 'dir' are given in this 'comp' local coordinate.
-!     pos  may or may not be inside comp.
-! if pos is outside of B.B, and partilce can cross B.B, the
-! length is to the XP. So to get length to the honeycomb,
-! this may be called again.  (then, no xp may happen)
-!
-       type(Component):: comp    ! input.  honeycomb
+c
+c    find length to the boundary of a honeycomb specfied by 
+c    'comp' from 'pos' with direction cos 'dir'
+c    'pos' and 'dir' are given in this 'comp' local coordinate.
+c     pos is may or may not be in side comp.
+c if pos is outside of B.B, and partilce can cross B.B, the
+c length is to the XP. So to get length to the honeycomb,
+c this may be called again.  (then, no xp may happen)
+c
+      record /Component/comp    ! input.  honeycomb
 
-       type(epPos)::  pos        ! input.  position.
-       type(epDirec)::  dir      ! input. direction cosinse
+      record /epPos/ pos        ! input.  position.
+      record /epDirec/ dir      ! input. direction cosinse
 
       real(8),intent(out):: length    !  length cm from pos to the boundary
       integer,intent(out):: icon  
@@ -233,8 +238,8 @@
           ! -1: the line dose not cross the volume
 
 
-       type(epPos)::  cpos        
-       type(epDirec)::  cdir      
+      record /epPos/ cpos        
+      record /epDirec/ cdir      
 
       call epv2c_honeycomb(comp, pos, cpos) !  local to canonical
       call epv2cd_honeycomb(comp, dir, cdir)  ! both pos and dir
@@ -260,7 +265,7 @@
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-       type(Component):: comp    ! input.  honeycomb
+      record /Component/comp    ! input.  honeycomb
      
       real(8),intent(in):: pos(3)  !  position.  canonical
       real(8),intent(in):: dir(3) !   direction cosinse. canonical
@@ -308,16 +313,16 @@
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-!
-!    find length to the boundary of a honeycomb specfied by 
-!    'comp' from 'pos' with direction cos 'dir'
-!    'pos' and 'dir' are given in this 'comp' local coordinate.
-!     pos  may or may not be inside comp.
+c
+c    find length to the boundary of a honeycomb specfied by 
+c    'comp' from 'pos' with direction cos 'dir'
+c    'pos' and 'dir' are given in this 'comp' local coordinate.
+c     pos is may or may not be in side comp.
 
-       type(Component):: comp    ! input.  honeycomb
+      record /Component/comp    ! input.  honeycomb
 
-       type(epPos)::  pos        ! input.  position.
-       type(epDirec)::  dir      ! input. direction cosinse
+      record /epPos/ pos        ! input.  position.
+      record /epDirec/ dir      ! input. direction cosinse
 
       real(8),intent(out):: length    !  length cm from pos to the boundary
       integer,intent(out):: icon      ! t 0: length obtained. pos    is inside
@@ -334,22 +339,22 @@
 !         (since search is done without such boundary)
 !         if (xb, yb) below is outside, we must reset
 !         the boundary
-         xb = pos%x + length*dir%x
-         yb = pos%y + length*dir%y
+         xb = pos.x + length*dir.x
+         yb = pos.y + length*dir.y
          lengc = 0
          if(xb < Xs ) then
             lengc = lengc + 1
-            leng(lengc) = (Xs-pos%x)/dir%x  ! dir.x should not be 0
+            leng(lengc) = (Xs-pos.x)/dir.x  ! dir.x should not be 0
          elseif(xb > Xs+a) then
             lengc = lengc + 1
-            leng(lengc) = ((Xs+a)-pos%x)/dir%x
+            leng(lengc) = ((Xs+a)-pos.x)/dir.x
          endif
          if(yb < Ys ) then
             lengc = lengc + 1
-            leng(lengc) = (Ys-pos%y)/dir%y
+            leng(lengc) = (Ys-pos.y)/dir.y
          elseif(yb > Ys+b) then
             lengc = lengc + 1
-            leng(lengc) = (Ys+b-pos%y)/dir%y
+            leng(lengc) = (Ys+b-pos.y)/dir.y
          endif
          if(lengc > 0 ) then
             minlen = 1.d20
@@ -365,7 +370,7 @@
       endif
       end  subroutine epbhoneycm0
 
-!   ***************************************
+c   ***************************************
       subroutine epbhoneycm1(comp, pos, dir, length, icon)
       use honeycomb
       implicit none
@@ -377,16 +382,16 @@
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-!
-!    find length to the boundary of a honeycomb specfied by 
-!    'comp' from 'pos' with direction cos 'dir'
-!    'pos' and 'dir' are given in this 'comp' local coordinate.
-!     pos  may or may not be inside comp.
+c
+c    find length to the boundary of a honeycomb specfied by 
+c    'comp' from 'pos' with direction cos 'dir'
+c    'pos' and 'dir' are given in this 'comp' local coordinate.
+c     pos is may or may not be in side comp.
 
-       type(Component):: comp    ! input.  honeycomb
+      record /Component/comp    ! input.  honeycomb
 
-       type(epPos)::  pos        ! input.  position.
-       type(epDirec)::  dir      ! input. direction cosinse
+      record /epPos/ pos        ! input.  position.
+      record /epDirec/ dir      ! input. direction cosinse
 
       real(8),intent(out):: length    !  length cm from pos to the boundary
       integer,intent(out):: icon      !  0: length obtained. pos    is inside
@@ -394,12 +399,12 @@
                      !       -1: the line dose not cross the volume
 
       real(8)::  el
-       type(epPos)::  p1, p2, p3, p4
-       type(epPos)::  OO, AA, BB, CC
-       type(epPos)::  OOp, AAp, BBp, CCp
-       type(epPos)::  xyz
-       type(epPos)::  normal
-       type(epDirec)::  dcos
+      record /epPos/ p1, p2, p3, p4
+      record /epPos/ OO, AA, BB, CC
+      record /epPos/ OOp, AAp, BBp, CCp
+      record /epPos/ xyz
+      record /epPos/ normal
+      record /epDirec/ dcos
 
       real(8):: x, y
 
@@ -413,18 +418,18 @@
 !          inpos is also set if inside
       call epshoneycm0(comp, pos, icon)   ! this should be cm0. 
 !          move to unit honeycomb coordinate.
-      x = pos%x - Xc
-      y = pos%y - Yc
+      x = pos.x - Xc
+      y = pos.y - Yc
 
       if(icon == 1 ) then
          ! pos is outside; see if it crosses top or bottom
          ! (prob. large)
          !      z =  pos.z + el*dir.z  = 0.
-         if( dir%z >0. ) then
+         if( dir.z >0. ) then
                !  we can assume pos.z >=0 and pos.z<=h
-            el = (h-pos%z)/dir%z
-            xb = x + el*dir%x
-            yb = y + el*dir%y
+            el = (h-pos.z)/dir.z
+            xb = x + el*dir.x
+            yb = y + el*dir.y
            ! see if xb,yb is in inner hexagon
             call ep_honeyin2(xb, yb,  kcon) 
             if( kcon == 0 ) then
@@ -432,10 +437,10 @@
                icon = -1
                return
             endif
-         elseif(dir%z < 0.) then
-            el = -pos%z/dir%z
-            xb = x + el*dir%x
-            yb = y + el*dir%y
+         elseif(dir.z < 0.) then
+            el = -pos.z/dir.z
+            xb = x + el*dir.x
+            yb = y + el*dir.y
            ! see if xb,yb is in inner hexagon
             call ep_honeyin2(xb, yb,  kcon) 
             if( kcon == 0 ) then
@@ -450,7 +455,7 @@
          !  No. 2 wall
          normal = epPos(0.d0, 1.d0, 0.d0)
          dd = Yl
-         xyz = epPos(x, y, pos%z)
+         xyz = epPos(x, y, pos.z)
 !           inner vertex  
          p1 = epPos(Xl, Yl, 0.d0)
          p2 = epPos(Xl, Yl, h)
@@ -459,10 +464,10 @@
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
 !///////////////////
-!            write(0,'(a,i3,1p,4G12.4)') 'w2 kcon, el', kcon, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c            write(0,'(a,i3,1p,4G12.4)') 'w2 kcon, el', kcon, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !///////////////////
          if(kcon .le. 4 .and. el >  0.d0 ) then
             length = el
@@ -480,10 +485,10 @@
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
 !///////////////////
-!            write(0,'(a,i3,1p,4G12.4)') 'w5 kcon el',kcon, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c            write(0,'(a,i3,1p,4G12.4)') 'w5 kcon el',kcon, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !///////////////////
          if(kcon .le. 4 .and. el > 0.d0) then
             length = el
@@ -502,10 +507,10 @@
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
 !///////////////
-!            write(0,'(a,i2,1p,4G12.4)') 'w1 kcon, el',kcon, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c            write(0,'(a,i2,1p,4G12.4)') 'w1 kcon, el',kcon, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !///////////////////
 
          if(kcon .le. 4 .and. el > 0.d0 ) then
@@ -525,10 +530,10 @@
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
 !///////////////
-!            write(0,'(a,i3,1p,4G12.4)') 'w4 kocn, el=',kcon,el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c            write(0,'(a,i3,1p,4G12.4)') 'w4 kocn, el=',kcon,el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !///////////////////
          if(kcon .le. 4 .and. el >  0.d0) then
             length = el
@@ -549,10 +554,10 @@
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
 !///////////////
-!            write(0,'(a,i3,1p,4G12.4)') 'w3,kcon,el=',kcon, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c            write(0,'(a,i3,1p,4G12.4)') 'w3,kcon,el=',kcon, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !///////////////////
          if(kcon .le. 4 .and. el > 0.d0) then
             length = el
@@ -571,10 +576,10 @@
          call epxpLand4vp2(p1, p2, p3, p4,
      *       xyz, dir, normal, dd, el, kcon, jcon)
 !///////////////
-!            write(0,'(a,i3,1p,4G12.4)') 'w6 kcon,el= ',kcon, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c            write(0,'(a,i3,1p,4G12.4)') 'w6 kcon,el= ',kcon, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !///////////////////
          if(kcon .le. 4 .and. el > 0.d0) then
             length = el
@@ -589,12 +594,12 @@
          AAp = epPos(Xu, Yu, 0.d0)
          BBp = epPos(Xu, Yu, h)
          CCp = epPos(Xl, Yl, h)
-         xyz = epPos(x, y, pos%z)
+         xyz = epPos(x, y, pos.z)
          dcos = dir
          if(inpos == 2 .or. inpos == 5) then
             if(inpos == 5) then
-               xyz%y = -xyz%y
-               dcos%y = -dcos%y
+               xyz.y = -xyz.y
+               dcos.y = -dcos.y
             endif
             OO=epPos(-Xl, Yl, 0.d0)
             AA=epPos(-Xl, Yl, h)
@@ -614,11 +619,11 @@
             call epxpLand4vp2(AAp, BBp, BB, CC,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,3g12.4)') 
-!     *          'ohw ',inpos, 
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,3g12.4)') 
+c     *          'ohw ',inpos, 
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon .le. 4 .and. el > 0.d0 ) then
                length = el
@@ -627,16 +632,16 @@
 !              2 --> 1 / wall
             normal =epPos(-sint/(1.d0-cost)*sqrt((1.0+cost)/2),
      *              sqrt( (1.0+cost)/2.), 0.d0)
-            dd = Xl*normal%x + Yl*normal%y
+            dd = Xl*normal.x + Yl*normal.y
 
             call epxpLand4vp2(AAp, BBp, CCp, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,3g12.4)') 
-!     *          'hw21 ',inpos, 
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,3g12.4)') 
+c     *          'hw21 ',inpos, 
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon .le. 4 .and. el > 0.d0) then
                length = el
@@ -645,16 +650,16 @@
 !            2 --> 3 / wall
             normal =epPos(sint/(1.d0-cost)*sqrt((1.0+cost)/2),
      *              sqrt( (1.0+cost)/2.), 0.d0)
-            dd =-Xl*normal%x + Yl*normal%y
+            dd =-Xl*normal.x + Yl*normal.y
 
             call epxpLand4vp2(CC, BB, AA, OO,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,3g12.4)') 
-!     *          'hw23 ',inpos, 
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,3g12.4)') 
+c     *          'hw23 ',inpos, 
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon .le. 4 .and. el > 0.d0) then
                length = el
@@ -667,11 +672,11 @@
             call epxpLand4vp2(AAp, CC, OO, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,3g12.4)') 
-!     *          'hb ',inpos, 
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,3g12.4)') 
+c     *          'hb ',inpos, 
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon .le. 4 .and. el > 0.d0) then
                length = el
@@ -684,11 +689,11 @@
             call epxpLand4vp2(BBp, BB, AA, CCp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,3g12.4)') 
-!     *          'ht ',inpos, 
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,3g12.4)') 
+c     *          'ht ',inpos, 
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon .le. 4 .and. el > 0.d0 ) then
                length = el
@@ -707,16 +712,16 @@
             if(inpos == 1) then
             elseif( inpos == 3 ) then
 !               mirror left right
-               xyz%x = - xyz%x
-               dcos%x  =  -dcos%x
+               xyz.x = - xyz.x
+               dcos.x  =  -dcos.x
             elseif( inpos == 4 ) then
-               xyz%x = - xyz%x
-               xyz%y = - xyz%y
-               dcos%x = - dcos%x
-               dcos%y = - dcos%y
+               xyz.x = - xyz.x
+               xyz.y = - xyz.y
+               dcos.x = - dcos.x
+               dcos.y = - dcos.y
             elseif( inpos == 6 ) then
-               xyz%y = - xyz%y
-               dcos%y = -dcos%y
+               xyz.y = - xyz.y
+               dcos.y = -dcos.y
             endif
 
             !    inner  wall by f1i
@@ -725,11 +730,11 @@
             call epxpLand4vp2(OO, CC, CCp, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,4g12.4)') 
-!     *          'iw ',inpos, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,4g12.4)') 
+c     *          'iw ',inpos, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon .le. 4 .and. el > 0.d0) then
                length = el
@@ -740,11 +745,11 @@
             call epxpLand4vp2(AA, BB, BBp, AAp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,4g12.4)') 
-!     *          'ow ',inpos, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,4g12.4)') 
+c     *          'ow ',inpos, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon .le. 4 .and. el > 0.d0) then
                length = el
@@ -756,11 +761,11 @@
             call epxpLand4vp(OO, AA, BB, CC, xyz, dcos,
      *        el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,4g12.4)') 
-!     *          'sw0 ',inpos, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,4g12.4)') 
+c     *          'sw0 ',inpos, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
 
             if(kcon .le. 4 .and. el > 0 ) then
@@ -770,16 +775,16 @@
 !            side wall between 1 and 2
             normal =epPos(-sint/(1.d0-cost)*sqrt((1.0+cost)/2),
      *              sqrt( (1.0+cost)/2.), 0.d0)
-            dd = Xl*normal%x + Yl*normal%y
+            dd = Xl*normal.x + Yl*normal.y
             
             call epxpLand4vp2(AAp, BBp,  CCp, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,4g12.4)') 
-!     *          'sw12 ',inpos, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,4g12.4)') 
+c     *          'sw12 ',inpos, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon <= 4  .and. el > 0.d0) then
                length = el
@@ -792,11 +797,11 @@
             call epxpLand4vp2(OO, AA, AAp, OOp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,4g12.4)') 
-!     *          'bot ',inpos, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,4g12.4)') 
+c     *          'bot ',inpos, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon <= 4 .and. el > 0.d0) then
                length = el
@@ -808,11 +813,11 @@
             call epxpLand4vp2(CC, BB, BBp, CCp,
      *       xyz, dcos, normal, dd, el, kcon, jcon)
 !////////////////////////
-!               write(0, '(a,i3,1p,4g12.4)') 
-!     *          'top ',inpos, el,
-!     *            el*dir.x+x+Xc,
-!     *            el*dir.y+y+Yc,
-!     *            el*dir.z+pos.z
+c               write(0, '(a,i3,1p,4g12.4)') 
+c     *          'top ',inpos, el,
+c     *            el*dir.x+x+Xc,
+c     *            el*dir.y+y+Yc,
+c     *            el*dir.z+pos.z
 !////////////////////////
             if(kcon <= 4  .and. el > 0.d0) then
                length = el
@@ -831,15 +836,15 @@
 #include "ZepDirec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-!
-!           judge if a given 'pos' is inside 'comp'
-!         
-       type(Component)::  comp !input honeycomb component 
-       type(epPos)::  pos  ! input. position in  local coord.
+c
+c           judge if a given 'pos' is inside 'comp'
+c         
+      record /Component/ comp !input honeycomb component 
+      record /epPos/ pos  ! input. position in  local coord.
       integer icon  ! output. 0--> pos is inside
                     !         1-->        outside
 
-       type(epPos)::  cpos   
+      record /epPos/ cpos   
 
 
       call epv2c_honeycomb(comp, pos, cpos)
@@ -855,11 +860,11 @@
 #include "ZepDirec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-!
-!           judge if a given 'pos' is inside 'comp'
-!         
-       type(Component)::  comp !input honeycomb component 
-       type(epPos)::  pos  ! input. position in  local coord.
+c
+c           judge if a given 'pos' is inside 'comp'
+c         
+      record /Component/ comp !input honeycomb component 
+      record /epPos/ pos  ! input. position in  local coord.
       integer icon  ! output. 0--> pos is inside
                     !         1-->        outside
 
@@ -870,18 +875,18 @@
       call ep_honeycmCnst(comp)
 
       inpos = 0
-      if( pos%z < 0. .or.  pos%z > h) then
+      if( pos.z < 0. .or.  pos.z > h) then
          icon = 1
-      elseif( pos%x < Xs .or. pos%x > Xs + a ) then
+      elseif( pos.x < Xs .or. pos.x > Xs + a ) then
          icon = 1
-      elseif( pos%y < Ys .or. pos%y > Ys + b ) then
+      elseif( pos.y < Ys .or. pos.y > Ys + b ) then
          icon = 1
       else
-         call ephoneyxy2unit(pos%x, pos%y,  jcon)
+         call ephoneyxy2unit(pos.x, pos.y,  jcon)
 !                 pos.x,y is in a unit  honeycomb (honeycomb may not be
 !                    closed one) 
-         x = pos%x - Xc
-         y = pos%y - Yc
+         x = pos.x - Xc
+         y = pos.y - Yc
          call ep_honeyin(x, y,  icon)
       endif
       end subroutine epshoneycm0
@@ -970,7 +975,7 @@
       icon = 1
       end subroutine  ep_honeyin2
 
-!     **************************************
+c     **************************************
       subroutine epenvlphoneycomb(comp, org, abc)
       use honeycomb
       implicit none
@@ -978,13 +983,13 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-!
-!        give the envloping box of the component
-!
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  org       ! output.  origin of the enveloping box
+c
+c        give the envloping box of the component
+c
+      record /Component/ comp  ! input.   component.
+      record /epPos/ org       ! output.  origin of the enveloping box
                                !          in local coord. 
-       type(ep3Vec)::  abc      ! output.  a,b,c of the box
+      record /ep3Vec/ abc      ! output.  a,b,c of the box
 
 
       call epenvlphoneycm0(comp, org, abc)
@@ -1001,27 +1006,27 @@
 #include "Zcnfig.h"
 #include "ZepPos.h"
 
-!
-!        give the envloping box of the component
-!
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  org       ! output.  origin of the enveloping box
+c
+c        give the envloping box of the component
+c
+      record /Component/ comp  ! input.   component.
+      record /epPos/ org       ! output.  origin of the enveloping box
                                !          in local coord. 
-       type(ep3Vec)::  abc      ! output.  a,b,c of the box
+      record /ep3Vec/ abc      ! output.  a,b,c of the box
 
 
 
       real*8  zmin, zmax
       integer n
-!
+c
       call ep_honeycmCnst(comp)
 
-      org%x = Xs
-      org%y = Ys
-      org%z = 0.
-      abc%x = a
-      abc%y = b
-      abc%z = h
+      org.x = Xs
+      org.y = Ys
+      org.z = 0.
+      abc.x = a
+      abc.y = b
+      abc.z = h
       NVTX = 0
       end  subroutine epenvlphoneycm0
 !     _____________________________ 
@@ -1034,17 +1039,17 @@
 #include "Zcnfig.h"
 #include "ZepPos.h"
 
-       type(Component)::  comp  ! input.   component.
-      if(CompNum /= comp%vol ) then
-         LL = Volat( comp%vol + 1)
-         LI = Volat( comp%vol + 2)
-         Ls = Volat( comp%vol + 3)
-         h = Volat( comp%vol + 4)
-         W = Volat( comp%vol + 5)
-         Xs = Volat( comp%vol + 6)
-         a =  Volat( comp%vol + 7)
-         Ys = Volat( comp%vol + 8)
-         b = Volat( comp%vol + 9)
+      record /Component/ comp  ! input.   component.
+      if(CompNum /= comp.vol ) then
+         LL = Volat( comp.vol + 1)
+         LI = Volat( comp.vol + 2)
+         Ls = Volat( comp.vol + 3)
+         h = Volat( comp.vol + 4)
+         W = Volat( comp.vol + 5)
+         Xs = Volat( comp.vol + 6)
+         a =  Volat( comp.vol + 7)
+         Ys = Volat( comp.vol + 8)
+         b = Volat( comp.vol + 9)
          if(LL < 0 ) then
             if(abs(LL) == 60.) then
                cost=0.5d0
@@ -1110,8 +1115,8 @@
 !         write(0,*) ' Yu, Yl, Xl=',Yu, Yl, Xl
 !         write(0,*) ' Xu, Xu0=', Xu, Xu0
 !c//////////////
-!         Compnum = comp.cn
-         Compnum = comp%vol
+c         Compnum = comp.cn
+         Compnum = comp.vol
       endif
 
       end subroutine ep_honeycmCnst
@@ -1212,7 +1217,7 @@
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
-       type(Component)::  comp   ! input.
+      record /Component/ comp   ! input.
       integer loc(*)
       integer i
       do i = 1, 9
@@ -1227,23 +1232,22 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-       type(Component)::  comp  ! input.   component. 
-       type(epPos)::  posv     ! input   
-       type(epPos)::  posc     ! output    can be posv
+      record /Component/ comp  ! input.   component. 
+      record /epPos/ posv     ! input   
+      record /epPos/ posc     ! output    can be posv
 
-       type(epPos)::  temp
+      record /epPos/ temp
 
       call ep_honeycmCnst(comp)
-      if( comp%struc  == 'honeycomb' .or.
-     *    comp%struc  == 'honeycomb_w'  ) then
+      if( comp.struc  == 'honeycomb' ) then
          posc = posv
-      elseif( comp%struc(1:12)  == 'honeycomb_xy' ) then
+      elseif( comp.struc  == 'honeycomb_xy' ) then
          posc = posv
-      elseif( comp%struc(1:12) == "honeycomb_yz" ) then
-         temp =epPos(posv%y, posv%z, posv%x)
+      elseif( comp.struc == "honeycomb_yz" ) then
+         temp =epPos(posv.y, posv.z, posv.x)
          posc = temp
-      elseif( comp%struc(1:12) == "honeycomb_zx" ) then
-         temp = epPos( posv%z, posv%x, posv%y)
+      elseif( comp.struc == "honeycomb_zx" ) then
+         temp = epPos( posv.z, posv.x, posv.y)
          posc = temp
 !      elseif( comp.struc == "honeycomb_x" ) then
 !         posc = posv
@@ -1252,7 +1256,7 @@
 !      elseif( comp.struc == "honeycomb_z" ) then
 !         posc = epPos( posv.z, b-posv.y, posv.x)
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epv2c_honeycomb is invalid'
          stop
       endif
@@ -1264,28 +1268,27 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  posc     ! input 
-       type(epPos)::  posv     ! output can be posc
+      record /Component/ comp  ! input.   component.
+      record /epPos/ posc     ! input 
+      record /epPos/ posv     ! output can be posc
 
-       type(epPos)::  temp
+      record /epPos/ temp
 
       call ep_honeycmCnst(comp)
-      if( comp%struc  == 'honeycomb' .or.
-     *    comp%struc  == 'honeycomb_w'  ) then
+      if( comp.struc  == 'honeycomb' ) then
          posv = posc
-      elseif( comp%struc(1:12)  == 'honeycomb_xy' ) then
+      elseif( comp.struc  == 'honeycomb_xy' ) then
          posv = posc
-      elseif( comp%struc(1:12) == "honeycomb_yz" ) then
+      elseif( comp.struc == "honeycomb_yz" ) then
 !                yzx:  y<->x   z<->y  x<->z
-         temp = epPos( posc%z, posc%x, posc%y)
+         temp = epPos( posc.z, posc.x, posc.y)
          posv = temp
-      elseif( comp%struc(1:12) == "honeycomb_zx" ) then
+      elseif( comp.struc == "honeycomb_zx" ) then
 !            zxy 
-         temp= epPos(posc%y, posc%z, posc%x)
+         temp= epPos(posc.y, posc.z, posc.x)
          posv = temp
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epc2v_honeycomb is invalid'
          stop
       endif
@@ -1297,24 +1300,23 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDirec.h"
-       type(Component)::  comp  ! input.   component.
-       type(epDirec)::  dirv     ! input
-       type(epDirec)::  dirc     ! output can be dirv
+      record /Component/ comp  ! input.   component.
+      record /epDirec/ dirv     ! input
+      record /epDirec/ dirc     ! output can be dirv
 
-       type(epDirec)::  temp
+      record /epDirec/ temp
 
       call ep_honeycmCnst(comp)
-      if( comp%struc  == 'honeycomb' .or.
-     *    comp%struc  == 'honeycomb_w'  ) then
+      if( comp.struc  == 'honeycomb' ) then
          dirc = dirv
-      elseif( comp%struc(1:12)  == 'honeycomb_xy' ) then
+      elseif( comp.struc  == 'honeycomb_xy' ) then
          dirc = dirv
-      elseif( comp%struc(1:12) == "honeycomb_yz" ) then
+      elseif( comp.struc == "honeycomb_yz" ) then
 !          yzx
-         temp = epDirec(dirv%y, dirv%z, dirv%x)
+         temp = epDirec(dirv.y, dirv.z, dirv.x)
          dirc = temp
-      elseif( comp%struc(1:12) == "honeycomb_zx" ) then
-         temp = epDirec(dirv%z, dirv%x, dirv%y)
+      elseif( comp.struc == "honeycomb_zx" ) then
+         temp = epDirec(dirv.z, dirv.x, dirv.y)
          dirc = temp
 !      elseif( comp.struc == "honeycomb_x" ) then
 !         dirc = dirv
@@ -1323,7 +1325,7 @@
 !      elseif( comp.struc == "honeycomb_z" ) then
 !         dirc = epDirec( dirv.z, -dirv.y, dirv.x)
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epv2cd_honeycomb is invalid'
          stop
       endif
@@ -1335,29 +1337,28 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDirec.h"
-       type(Component)::  comp  ! input.   component.
-       type(epDirec)::  dirc     ! input
-       type(epDirec)::  dirv     ! output can be dirc
+      record /Component/ comp  ! input.   component.
+      record /epDirec/ dirc     ! input
+      record /epDirec/ dirv     ! output can be dirc
 
-       type(epDirec)::  temp
+      record /epDirec/ temp
       call ep_honeycmCnst(comp)
 !     (X,Y,Z)<---(x,y,z)
-      if( comp%struc  == 'honeycomb' .or.
-     *    comp%struc  == 'honeycomb_w' ) then
+      if( comp.struc  == 'honeycomb' ) then
          dirv = dirc
-      elseif( comp%struc(1:12)  == 'honeycomb_xy' ) then
+      elseif( comp.struc  == 'honeycomb_xy' ) then
          dirv = dirc
-      elseif( comp%struc(1:12) == "honeycomb_yz" ) then
+      elseif( comp.struc == "honeycomb_yz" ) then
 !         cdir = epDirec(dir.y, dir.z, dir.x)  X:y  Y:z  Z:x
 !                 yzx
-         temp = epDirec(dirc%z, dirc%x, dirc%y)
+         temp = epDirec(dirc.z, dirc.x, dirc.y)
          dirv = temp
-      elseif( comp%struc(1:12)  == 'honeycomb_zx' ) then
+      elseif( comp.struc  == 'honeycomb_zx' ) then
 !         cdir = epDirec(dir.z, dir.x, dir.y)  X:z Y:x Z:y 
-         temp = epDirec(dirc%y, dirc%z, dirc%x)
+         temp = epDirec(dirc.y, dirc.z, dirc.x)
          dirv = temp 
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epc2vd_honeycomb is invalid'
          stop
       endif
