@@ -40,26 +40,23 @@
 
 
 
-!
-!     see Fig/NewVol2.pdf 
-!      
+c
+c     see Fig/NewVol2.pdf 
+c      
       subroutine eprsqtccl(comp)
       implicit none
-#include "ZepManager.h"
 #include "Zep3Vec.h"
 #include "ZepPos.h"
 #include "Zcnfig.h"
-!
-!         interface to read configuration data for "sqtccl"
-!
-       type(Component)::  comp   ! output. to recieve the config data.
+c
+c         interface to read configuration data for "sqtccl"
+c
+      record /Component/ comp   ! output. to recieve the config data.
 
 !             next is mandatory
       call eprpst(comp, 4, 8, 1, 6)
       call ep_sqtcclCnst0(comp)
-      if(MsgLevel >= 2 ) then
-         call ep_sqtcclPrintCnst
-      endif
+      call ep_sqtcclPrintCnst
 
       end subroutine eprsqtccl
 
@@ -69,20 +66,25 @@
       use sqtccl
       implicit none
 #include "ZepTrackp.h"
+c//////////////
 #include "ZepTrackv.h"
+c///////////
+c #include "Zep3Vec.h"
+c #include "ZepPos.h"
 #include "Zcnfig.h"
+c  #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-!
-!    find length to the boundary of a sqtccl specfied by 
-!    'comp' from 'pos' with direction cos 'dir'
-!    'pos' and 'dir' are given in this 'comp' local coordinate.
-!     pos is may or may not be inside comp.
+c
+c    find length to the boundary of a sqtccl specfied by 
+c    'comp' from 'pos' with direction cos 'dir'
+c    'pos' and 'dir' are given in this 'comp' local coordinate.
+c     pos is may or may not be inside comp.
 
-       type(Component):: comp    ! input.  sqtccl
+      record /Component/comp    ! input.  sqtccl
 
-       type(epPos)::  pos        ! input.  position.
-       type(epDirec)::  dir      ! input. direction cosinse
+      record /epPos/ pos        ! input.  position.
+      record /epDirec/ dir      ! input. direction cosinse
 
       real(8),intent(out):: length    !  length cm from pos to the boundary
       integer,intent(out):: icon      !  0: length obtained. pos    is inside
@@ -90,13 +92,19 @@
                      !       -1: the line dose not cross the volume
 
       real(8)::el
-       type(epPos)::  cpos
-       type(epDirec)::  cdir 
+      record /epPos/ cpos
+      record /epDirec/ cdir 
 
+!c///////////////
+!      record /epPos/ posw
+!        -3.9228656       2.3623865     -0.68090251
+!        -3.9279674       2.3714778     
 !   
       call epv2c_sqtccl(comp, pos, cpos)    ! for _y _x, get canonical pos
       call epv2cd_sqtccl(comp, dir, cdir)     ! and dir
 
+
+
       call epbsqtccl0(comp, cpos, cdir, length, icon)
 
       end subroutine epbsqtccl
@@ -113,16 +121,16 @@
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-!
-!    find length to the boundary of a sqtccl specfied by 
-!    'comp' from 'pos' with direction cos 'dir'
-!    'pos' and 'dir' are given in canonical  'comp'  coordinate.
-!     pos is may or may not be inside comp.
+c
+c    find length to the boundary of a sqtccl specfied by 
+c    'comp' from 'pos' with direction cos 'dir'
+c    'pos' and 'dir' are given in canonical  'comp'  coordinate.
+c     pos is may or may not be inside comp.
 
-       type(Component):: comp    ! input.  sqtccl
+      record /Component/comp    ! input.  sqtccl
 
-       type(epPos)::  pos        ! input.  position.
-       type(epDirec)::  dir      ! input. direction cosinse
+      record /epPos/ pos        ! input.  position.
+      record /epDirec/ dir      ! input. direction cosinse
 
       real(8),intent(out):: length    !  length cm from pos to the boundary
       integer,intent(out):: icon      !  0: length obtained. pos    is inside
@@ -131,23 +139,22 @@
 
       real(8)::el, temp
 
-       type(epPos)::  org, abc
+      record /epPos/ org, abc
       
       call epenvlpsqtccl0(comp, org, abc)
 !           see bounding box (el is length to xing point, 
 !           if any, else icon =-1
-      call kxplbx( pos%x-org%x, pos%y-org%y, pos%z-org%z, 
-     *               dir%x, dir%y, dir%z, 
-     *               abc%x, abc%y, abc%z, el, icon)
-
+      call kxplbx( pos.x-org.x, pos.y-org.y, pos.z-org.z, 
+     *               dir.x, dir.y, dir.z, 
+     *               abc.x, abc.y, abc.z, el, icon)
       if(icon == -1)  return  ! no crossing 
       if(icon == 1)  then
 !            pos is outside but may cross
-         if( pos%z  < 0.) then
-            if( abs(pos%z+ el*dir%z) < eps ) then
-               temp =pos%x + el*dir%x 
+         if( pos.z  < 0.) then
+            if( abs(pos.z+ el*dir.z) < eps ) then
+               temp =pos.x + el*dir.x 
                if( temp > -a .and. temp < a ) then
-                  temp =pos%y + el*dir%y
+                  temp =pos.y + el*dir.y
                   if(temp > -b .and. temp< b) then
 !                    xp is at bottom
                      length = el ! xing with the bottom
@@ -163,7 +170,6 @@
 !          see if pos is inside. next is exact (polygon approx. of ccl
 !          is consideed)
          call epssqtccl0(comp, pos, icon)
-
          topbot = 0  !  used delicate case where wall may intercept 
                      !  inner point and ceil or floor.
          if(icon ==  0 ) then
@@ -189,16 +195,16 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 
-       type(Component):: comp    ! input.  sc2ccl
+      record /Component/comp    ! input.  sc2ccl
 
-       type(epPos)::  pos
-       type(epDirec)::  dir
+      record /epPos/ pos
+      record /epDirec/ dir
       real(8),intent(out):: el  ! length to the boundary
 
       real(8)::x, y
       integer::icon, jcon, kcon
-       type(epPos)::  posh
-       type(epPos)::  p1, p2, p3, p4
+      record /epPos/ posh
+      record /epPos/ p1, p2, p3, p4
       integer::q
       real(8):: el1, el2, es1, es2, temp, elsave
       real(8):: fai1, fai2, faiin, fai, Dfai
@@ -206,16 +212,16 @@
       integer inout
 
 
-      posIsInSq  = -a <= pos%x .and. pos%x<=a
-     *       .and. -b <= pos%y .and. pos%y<=b .and. boxInside
+      posIsInSq  = -a <= pos.x .and. pos.x<=a
+     *       .and. -b <= pos.y .and. pos.y<=b .and. boxInside
       inout = -1
       delicate = .false.
-      if(dir%z /= 0.0) then
+      if(dir.z /= 0.0) then
 !          see bottom
-         el = -pos%z/dir%z
+         el = -pos.z/dir.z
          if(el > 0.) then
-            x = pos%x + el*dir%x
-            y = pos%y + el*dir%y
+            x = pos.x + el*dir.x
+            y = pos.y + el*dir.y
             if(x >= -a .and. x<= a) then
                if( y >= -b .and. y<= b) then
                   if( posIsInSq ) then
@@ -230,13 +236,13 @@
             endif
          endif
 !           see top
-         posIsInCcl = pos%x**2 + pos%y**2 <= ri**2 .and. cylinderInside
+         posIsInCcl = pos.x**2 + pos.y**2 <= ri**2 .and. cylinderInside
 
-         el = (h-pos%z)/dir%z
+         el = (h-pos.z)/dir.z
          if( el > 0.)  then
             elsave = el
-            x = pos%x + el*dir%x
-            y = pos%y + el*dir%y
+            x = pos.x + el*dir.x
+            y = pos.y + el*dir.y
             if( x**2 + y**2  <= ri**2) then  ! inside inner circle
                if( posIsInCcl) then
                   return
@@ -250,23 +256,25 @@
                call epsqtcclStepFai(faiin, fai, Dfai)
                call epsqtcclGet4p(fai, Dfai, p1, p2, p3, p4, q)
                call k3inout(x, y,
-     *              0.d0, 0.d0, p1%x, p1%y,  p4%x, p4%y, inout)
-!               if(icon == 0 ) then
-!                  return
-!               endif
+     *              0.d0, 0.d0, p1.x, p1.y,  p4.x, p4.y, inout)
+c               if(icon == 0 ) then
+c                  return
+c               endif
                if(inout == 0 ) then
+c                  write(0,*) ' ssqtccl0 and k3inout conflicts'
+c                  write(0,*) ' use inout'
                   if( posIsInCcl ) then
                      return
                   endif
                   topbot = 1
                endif
                delicate = posIsInCcl
-!               if(inout == 1 .and. icon == 1) then
-!                  write(0,*)' pos and triagle'
-!                  write(0,*) ' x,y=', pos.x, pos.y
-!                  write(0,*) ' 1st p=', p1.x, p1.y
-!                  write(0,*) ' 2nd p=', p4.x, p4.y
-!               endif
+c               if(inout == 1 .and. icon == 1) then
+c                  write(0,*)' pos and triagle'
+c                  write(0,*) ' x,y=', pos.x, pos.y
+c                  write(0,*) ' 1st p=', p1.x, p1.y
+c                  write(0,*) ' 2nd p=', p4.x, p4.y
+c               endif
             else
                inout = 2
             endif
@@ -277,53 +285,53 @@
 !         x-ing point should be  on the side wall
 !         get fai region to inspect
 !            get xp with ccl  on the projection
-      call kxplccl(pos%x, pos%y, dir%x, dir%y, r, el1, el2, jcon)
+      call kxplccl(pos.x, pos.y, dir.x, dir.y, r, el1, el2, jcon)
           !     jcon = 0 pos is inside ccl. el1 is usable
           !            1 pos is outside el1 and el2 are xp
           !           -1 no xp 
           ! see xp with square
-      call kxplsq(pos%x+a, pos%y+b, dir%x, dir%y,
+      call kxplsq(pos.x+a, pos.y+b, dir.x, dir.y,
      *      2.d0*a, 2.d0*b, es1, es2, kcon)
           !  kcon: same meaning as jcon above.
 
-      fai1 = atan2(pos%y, pos%x)
+      fai1 = atan2(pos.y, pos.x)
       if( jcon ==  0 .and. kcon == 0 ) then
          ! xpoint should be between  pos ~ max(es1,el1) 
          if( es1 > el1 ) then
-            fai2 = atan2(pos%y+es1*dir%y, pos%x + es1*dir%x)
+            fai2 = atan2(pos.y+es1*dir.y, pos.x + es1*dir.x)
          else
-            fai2 = atan2(pos%y+el1*dir%y, pos%x + el1*dir%x) 
+            fai2 = atan2(pos.y+el1*dir.y, pos.x + el1*dir.x) 
          endif
        elseif( jcon == 1 .and.  kcon == 0 ) then
           if( es1 >  el2 ) then
-             fai2 = atan2(pos%y+es1*dir%y, pos%x + es1*dir%x)
+             fai2 = atan2(pos.y+es1*dir.y, pos.x + es1*dir.x)
           else
-             fai2 = atan2(pos%y+el2*dir%y, pos%x + el2*dir%x) 
+             fai2 = atan2(pos.y+el2*dir.y, pos.x + el2*dir.x) 
           endif
        elseif( jcon == 0 .and. kcon == 1 ) then
           ! ccl is larger than square; es2 ~ el1
           if( es2 > el1 ) then
-             fai2 = atan2(pos%y+es2*dir%y, pos%x + es2*dir%x)
+             fai2 = atan2(pos.y+es2*dir.y, pos.x + es2*dir.x)
           else
-             fai2 = atan2(pos%y+el1*dir%y, pos%x + el1*dir%x) 
+             fai2 = atan2(pos.y+el1*dir.y, pos.x + el1*dir.x) 
           endif
        elseif( jcon == -1 .and. kcon == 0 ) then
           !  pos~ es1
-          fai2 = atan2(pos%y+es1*dir%y, pos%x + es1*dir%x)
+          fai2 = atan2(pos.y+es1*dir.y, pos.x + es1*dir.x)
        elseif( jcon == 0 .and. kcon == -1) then
           ! pos ~ el1
-          fai2 = atan2(pos%y+el1*dir%y, pos%x + el1*dir%x)
+          fai2 = atan2(pos.y+el1*dir.y, pos.x + el1*dir.x)
        elseif( jcon == 1 .and. kcon == -1 ) then
-          fai2 = atan2(pos%y+el2*dir%y, pos%x + el2*dir%x) 
+          fai2 = atan2(pos.y+el2*dir.y, pos.x + el2*dir.x) 
        elseif( jcon == -1 .and. kcon == 1 ) then
-          fai2 = atan2(pos%y+es2*dir%y, pos%x + es2*dir%x)
+          fai2 = atan2(pos.y+es2*dir.y, pos.x + es2*dir.x)
        elseif( jcon == 1 .and. kcon == 1 ) then  
           if(es2 > el2) then
              fai2 = 
-     *            atan2(pos%y+es2*dir%y, pos%x + es2*dir%x)
+     *            atan2(pos.y+es2*dir.y, pos.x + es2*dir.x)
           else
              fai2 = 
-     *            atan2(pos%y+el2*dir%y, pos%x + el2*dir%x) 
+     *            atan2(pos.y+el2*dir.y, pos.x + el2*dir.x) 
           endif
        else
 !     can happen 
@@ -391,35 +399,35 @@
          endif
 
          write(0,*)
-     *    ' No crossing is strange in ep_sqtccl;cn= ', comp%cn 
-         write(0,*) ' struc=',comp%struc
+     *    ' No crossing is strange in ep_sqtccl;cn= ', comp.cn 
+         write(0,*) ' struc=',comp.struc
          write(0,*) 'icon=',icon,' jcon=', jcon, ' kcon =',kcon
          write(0,*) ' inout =', inout, ' topbot=',topbot
 
          write(0,'(a, 1p,3g16.8)') ' canonical pos  =', pos
          posh =
-     *    epPos(pos%x+15*dir%x, pos%y+15*dir%y,  pos%z+15*dir%z)
+     *    epPos(pos.x+15*dir.x, pos.y+15*dir.y,  pos.z+15*dir.z)
          write(0,'(a, 1p,3g16.8)') ' canonical pos2 =', posh
          write(0,'(a,1p,3g16.7)') ' dir =', dir
-         write(0, *)  ' fai(deg)=', atan2(dir%y, dir%x)/Torad
+         write(0, *)  ' fai(deg)=', atan2(dir.y, dir.x)/Torad
          call epc2v_sqtccl(comp, pos, pos)
-         call epl2w(comp%cn,  pos, pos)
+         call epl2w(comp.cn,  pos, pos)
          call epc2v_sqtccl(comp, posh, posh)
-         call epl2w(comp%cn,  posh, posh)
+         call epl2w(comp.cn,  posh, posh)
          call epc2vd_sqtccl(comp, dir, dir)
-         call epl2wd(comp%cn, dir, dir)
+         call epl2wd(comp.cn, dir, dir)
          write(0,*) ' world pos  ='
          write(0,*)  pos
          write(0,*) ' world pos2 ='
          write(0,*)  posh
          write(0,*) ' world dir ='
          write(0,*)  dir
-         write(0,*)  ' fai=', atan2(dir%y, dir%x)/Torad
+         write(0,*)  ' fai=', atan2(dir.y, dir.x)/Torad
          write(0,*) ' canonical fai region fai1 =', fai1/Torad,
      *    ' fai2 =',fai2/Torad
-!         write(0,*) '-------------------'
-!         call epfordebug('from sqTcll')
-!         write(0,*) '-------------------'
+c         write(0,*) '-------------------'
+c         call epfordebug('from sqTcll')
+c         write(0,*) '-------------------'
          stop
       endif
       end subroutine epbsqtcclin
@@ -435,13 +443,13 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 
-       type(Component):: comp    ! input.  sc2ccl
-       type(epPos)::  pos
-       type(epDirec)::  dir
+      record /Component/comp    ! input.  sc2ccl
+      record /epPos/ pos
+      record /epDirec/ dir
       real(8),intent(out)::length
       integer,intent(out)::icon  ! 1 if cross -1 if no
 
-       type(epPos)::  posh
+      record /epPos/ posh
       real(8)::x, y
       integer:: face
       real(8)::el, fai1, fai2      
@@ -451,17 +459,17 @@
 
       xpc = 0
 !         first check if x with bounding horse
-      posh = epPos( pos%x + a, pos%y + b, pos%z)
+      posh = epPos( pos.x + a, pos.y + b, pos.z)
       call kxplhorse(2.0d0*a, 2.0d0*b, h, a-r, b-r, 
      *  2.d0*r, 2.d0*r, posh, dir,  el, icon, face)
       if(icon == -1) then
          return                 !************  no crossing
       endif
 !             from top side.
-      if(face == 6 .and.  dir%z <  0.0 .and. pos%z > h ) then
-         el =  (h-pos%z)/dir%z
-         x = pos%x + el*dir%x
-         y = pos%y + el*dir%y
+      if(face == 6 .and.  dir.z <  0.0 .and. pos.z > h ) then
+         el =  (h-pos.z)/dir.z
+         x = pos.x + el*dir.x
+         y = pos.y + el*dir.y
          if(x**2 + y**2 < ri**2 ) then
             icon = 1
             length = el
@@ -523,7 +531,7 @@
       end    subroutine epbsqtcclot
 
 
-!   ***************************************
+c   ***************************************
       subroutine epsqtcclStepFai(faiin, fai, Dfai)
       use sqtccl
       real(8),intent(in):: faiin ! may be < 0, >twopi
@@ -575,7 +583,7 @@
  
       real(8),intent(in):: faiin  ! >=0  must be stepped one
       real(8),intent(in):: Dfai
-       type(epPos):: p1, p2, p3, p4
+      record /epPos/p1, p2, p3, p4
       integer,intent(out)::q  ! on of 1, 2,3,4 which quadrant  
       
       real(8):: fai, temp
@@ -659,8 +667,8 @@
 #include "ZepPos.h"
 #include "ZepDirec.h"
 
-       type(epPos)::  pos
-       type(epDirec)::  dir
+      record /epPos/ pos
+      record /epDirec/ dir
       real(8),intent(in)::ifai1, ifai2
       integer,intent(in):: io !  0 pos is inside 1 pos is outside
       real(8),intent(out)::length
@@ -673,7 +681,7 @@
 
       integer:: xpc,  jcon
       real(8):: ela(2), temp, x, el
-       type(epPos)::  p1, p2, p3, p4
+      record /epPos/ p1, p2, p3, p4
       real(8):: towhich
       integer:: q
 
@@ -738,9 +746,9 @@
       end subroutine epxpsqtcclW
 
       subroutine epssqtccl(comp, pos, icon)
-!
-!           judge if a given 'pos' is inside 'comp'
-!         
+c
+c           judge if a given 'pos' is inside 'comp'
+c         
       use sqtccl
       implicit none
 
@@ -749,20 +757,20 @@
 #include "ZepPos.h"
 #include "Zcnfig.h"
 
-       type(Component)::  comp !input sqtccl component 
-       type(epPos)::  pos  ! input. position in  local coord.
+      record /Component/ comp !input sqtccl component 
+      record /epPos/ pos  ! input. position in  local coord.
       integer icon  ! output. 0--> pos is inside
                     !         1-->        outside
 
-       type(epPos)::  cpos
+      record /epPos/ cpos
       call epv2c_sqtccl(comp, pos, cpos)
       call epssqtccl0(comp, cpos, icon)
       end      subroutine epssqtccl
 
       subroutine epssqtccl0(comp, pos, icon)
-!
-!           judge if a given 'pos' is inside 'comp'
-!         
+c
+c           judge if a given 'pos' is inside 'comp'
+c         
       use sqtccl
       implicit none
 
@@ -771,30 +779,31 @@
 #include "ZepPos.h"
 #include "Zcnfig.h"
 
-       type(Component)::  comp !input sqtccl component 
-       type(epPos)::  pos  ! input. position in  local coord.
+      record /Component/ comp !input sqtccl component 
+      record /epPos/ pos  ! input. position in  local coord.
       integer icon  ! output. 0--> pos is inside
                     !         1-->        outside
 
-       type(epPos)::  org, abc
+      record /epPos/ org, abc
 
-      if(pos%z > h ) then
+      if(pos.z > h ) then
          icon = 1 
          return
-      elseif(pos%z < 0.d0) then
+      elseif(pos.z < 0.d0) then
          icon = 1
          return
       endif
 
       call epenvlpsqtccl0(comp, org, abc)
-      call kseeinbox(org%x, org%x + abc%x,
-     *               org%y, org%y + abc%y,
-     *               org%z, org%z + abc%z,
-     *     pos%x, pos%y, pos%z, icon)
+      call kseeinbox(org.x, org.x + abc.x,
+     *               org.y, org.y + abc.y,
+     *               org.z, org.z + abc.z,
+     *     pos.x, pos.y, pos.z, icon)
       !  if not in the bounding box, outside
       if(icon == 1 ) return
       !  further check
       call  epssqtccl1(comp, pos, icon)
+
       end subroutine epssqtccl0
 
 
@@ -808,18 +817,18 @@
 #include "ZepPos.h"
 #include "Zcnfig.h"
 
-!
-!           judge if a given 'pos' is inside 'comp'
-!         
-       type(Component)::  comp !input sqtccl component 
-       type(epPos)::  pos  ! input. position in  local coord.
+c
+c           judge if a given 'pos' is inside 'comp'
+c         
+      record /Component/ comp !input sqtccl component 
+      record /epPos/ pos  ! input. position in  local coord.
       integer icon  ! output. 0--> pos is inside
                     !         1-->        outside
 
 
-       type(epPos)::  p1, p2, p3, p4
-       type(epPos)::  p14, p32, vprod
-       type(ep3Vec)::  nm 
+      record /epPos/ p1, p2, p3, p4
+      record /epPos/ p14, p32, vprod
+      record /ep3Vec/ nm 
       real(8):: k,  faiij, fai, temp, fais, Dfai
       real(8):: diff1,  diff2
       integer:: j, q
@@ -827,17 +836,17 @@
 
       if( cylinderInside ) then
          call kseeincyl(0.d0, 0.d0, 0.d0, ri, h, 
-     *        pos%x, pos%y, pos%z, icon)
+     *        pos.x, pos.y, pos.z, icon)
         ! if inside of inner inscribing cyl, then inside
          if(icon == 0 ) return
       elseif( boxInside) then
          call kseeinbox(-a, a, -b, b, 0.d0, h,
-     *      pos%x, pos%y, pos%z, icon)
+     *      pos.x, pos.y, pos.z, icon)
         ! if inside of inner box, then inside
          if(icon == 0 ) return
       endif
 
-      fai = atan2(pos%y, pos%x)
+      fai = atan2(pos.y, pos.x)
       call epsqtcclStepFai(fai,  fais, Dfai)
       call epsqtcclGet4p(fais, Dfai, p1, p2, p3, p4,q)
       call epwhichside0(p1, p2, p3, pos, nm, k, diff1)
@@ -851,14 +860,14 @@
          return
       endif
 !       very delicate point  which is very near to the surface
-      p14%x = p4%x - p1%x
-      p14%y = p4%y - p1%y
-      p14%z = 0.d0
-      p32%x = p2%x - p3%x
-      p32%y = p2%y - p3%y
-      p32%z = 0.d0
+      p14.x = p4.x - p1.x
+      p14.y = p4.y - p1.y
+      p14.z = 0.d0
+      p32.x = p2.x - p3.x
+      p32.y = p2.y - p3.y
+      p32.z = 0.d0
       call epvectorProd(p14, p32, vprod)
-      if( vprod%z < 0.) then 
+      if( vprod.z < 0.) then
          icon = 0
          return
       else
@@ -869,7 +878,7 @@
       end subroutine epssqtccl1
 
 
-!     **************************************
+c     **************************************
       subroutine epenvlpsqtccl(comp, org, abc)
       use sqtccl
       implicit none
@@ -879,13 +888,13 @@
 #include "Zcnfig.h"
 
 
-!
-!        give the envloping box of the component
-!
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  org       ! output.  origin of the enveloping box
+c
+c        give the envloping box of the component
+c
+      record /Component/ comp  ! input.   component.
+      record /epPos/ org       ! output.  origin of the enveloping box
                                !          in local coord. 
-       type(ep3Vec)::  abc      ! output.  a,b,c of the box
+      record /ep3Vec/ abc      ! output.  a,b,c of the box
 
 
       call ep_sqtcclCnst(comp)
@@ -893,7 +902,7 @@
       call  epenvlpsqtccl1(comp, org, abc)
       end      subroutine epenvlpsqtccl
 
-!     *******************************
+c     *******************************
       subroutine epenvlpsqtccl0(comp, org, abc)
       use sqtccl
       implicit none
@@ -901,26 +910,26 @@
 #include "Zep3Vec.h"
 #include "ZepPos.h"
 #include "Zcnfig.h"
-!             note: ..ccl, ..ccl0 ..ccl1  are
-!                ..ccl0 : canonical
-!                ..ccl1 : to local
-!          different from epbsqtccl, ccl0, ccl1
-!                   ccl0:  local   ccl1: canonical
-!        give the envloping box of the component
-!
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  org       ! output.  origin of the enveloping box
+c             note: ..ccl, ..ccl0 ..ccl1  are
+c                ..ccl0 : canonical
+c                ..ccl1 : to local
+c          different from epbsqtccl, ccl0, ccl1
+c                   ccl0:  local   ccl1: canonical
+c        give the envloping box of the component
+c
+      record /Component/ comp  ! input.   component.
+      record /epPos/ org       ! output.  origin of the enveloping box
                                !          in canonical coord. 
-       type(ep3Vec)::  abc      ! output.  a,b,c of the box
+      record /ep3Vec/ abc      ! output.  a,b,c of the box
 
-!
+c
 
-      org%x =min( -a, -r)
-      org%y =min( -b, -r)
-      org%z = 0.
-      abc%x = abs(org%x*2)
-      abc%y = abs(org%y*2)
-      abc%z = h
+      org.x =min( -a, -r)
+      org.y =min( -b, -r)
+      org.z = 0.
+      abc.x = abs(org.x*2)
+      abc.y = abs(org.y*2)
+      abc.z = h
       NVTX = 0
 
       end  subroutine epenvlpsqtccl0
@@ -932,26 +941,26 @@
 #include "Zep3Vec.h"
 #include "ZepPos.h"
 #include "Zcnfig.h"
-!
-!        give the envloping box of the component
-!
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  org       ! in/output.  origin of the enveloping box
+c
+c        give the envloping box of the component
+c
+      record /Component/ comp  ! input.   component.
+      record /epPos/ org       ! output.  origin of the enveloping box
                                !          in local coord. 
-       type(ep3Vec)::  abc      ! in/output.  a,b,c of the box
+      record /ep3Vec/ abc      ! output.  a,b,c of the box
       real(8):: temp
 
 
-      if(comp%struc == 'sqtccl_y') then
+      if(comp.struc == 'sqtccl_y') then
          !  y<->z
-         temp = abc%y
-         abc = ep3Vec(abc%x, abc%z, temp)
-         org =epPos(org%x, 0.d0, -max(a,r))
-      elseif(comp%struc == 'sqtccl_x') then
+         temp = abc.y
+         abc = ep3Vec(abc.x, abc.z, temp)
+         org =epPos(org.x, 0.d0, -max(a,r))
+      elseif(comp.struc == 'sqtccl_x') then
          !  z<-->x
-         temp = abc%x
-         abc = ep3Vec(abc%z, abc%y, temp)
-         org =epPos(0.d0, org%y, -max(a,r))
+         temp = abc.x
+         abc = ep3Vec(abc.z, abc.y, temp)
+         org =epPos(0.d0, org.y, -max(a,r))
       endif
 !                This dose not work.  do as above
 !      call epc2v_sqtccl(comp, org, org)
@@ -969,14 +978,14 @@
 #include "ZepPos.h"
 #include "Zcnfig.h"
       
-       type(Component)::  comp  ! input.   component.
+      record /Component/ comp  ! input.   component.
 
       real(8):: temp
-!           check
-         a = Volat( comp%vol + 1)
-         b = Volat( comp%vol + 2)
-         h = Volat( comp%vol + 3) 
-         r = Volat( comp%vol + 4) 
+c           check
+         a = Volat( comp.vol + 1)
+         b = Volat( comp.vol + 2)
+         h = Volat( comp.vol + 3) 
+         r = Volat( comp.vol + 4) 
          Fai0 = atan2(b,a)
          Nfai1 = Npolygon/4*b/(a+b) + 0.5d0
          Nfai2 = Npolygon/4- Nfai1
@@ -989,10 +998,10 @@
             temp = Dfai2
          endif
          ri = r *cos(temp/2.d0)    ! inscribing ccl radius
-         Volat(comp%vol + 5)  = ri
-         Volat(comp%vol + 6)  = Fai0
-         Volat(comp%vol + 7)  = Dfai1
-         Volat(comp%vol + 8)  = Dfai2
+         Volat(comp.vol + 5)  = ri
+         Volat(comp.vol + 6)  = Fai0
+         Volat(comp.vol + 7)  = Dfai1
+         Volat(comp.vol + 8)  = Dfai2
       end  subroutine ep_sqtcclCnst0
       subroutine ep_sqtcclCnst(comp)
 !      set consts 
@@ -1003,18 +1012,18 @@
 #include "ZepPos.h"
 #include "Zcnfig.h"
 
-       type(Component)::  comp  ! input.   component.
+      record /Component/ comp  ! input.   component.
 
-!      if(comp.cn /= Compnum ) then  !  honeycomb
-      if(comp%vol /= Compnum ) then
-         a = Volat( comp%vol + 1)
-         b = Volat( comp%vol + 2)
-         h = Volat( comp%vol + 3) 
-         r = Volat( comp%vol + 4) 
-         ri = Volat( comp%vol + 5) 
-         Fai0 =Volat(comp%vol + 6)  
-         Dfai1 = Volat(comp%vol + 7) 
-         Dfai2 = Volat(comp%vol + 8)  
+c      if(comp.cn /= Compnum ) then  !  honeycomb
+      if(comp.vol /= Compnum ) then
+         a = Volat( comp.vol + 1)
+         b = Volat( comp.vol + 2)
+         h = Volat( comp.vol + 3) 
+         r = Volat( comp.vol + 4) 
+         ri = Volat( comp.vol + 5) 
+         Fai0 =Volat(comp.vol + 6)  
+         Dfai1 = Volat(comp.vol + 7) 
+         Dfai2 = Volat(comp.vol + 8)  
          if( r <= min(a,b)) then
             cylinderInside = .true.
             boxInside = .false.
@@ -1033,7 +1042,7 @@
          Nfai1 = Npolygon/4*a/(a+b) + 0.5d0
          Nfai2 = Npolygon/4- Nfai1
 !         Compnum = comp.cn
-         Compnum = comp%vol
+         Compnum = comp.vol
       endif
       end  subroutine ep_sqtcclCnst
 
@@ -1055,7 +1064,7 @@
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
-       type(Component)::  comp   ! input.
+      record /Component/ comp   ! input.
       integer loc(*)
       integer i
       do i = 1, 4
@@ -1070,22 +1079,21 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  posv     ! input
-       type(epPos)::  posc     ! output
+      record /Component/ comp  ! input.   component.
+      record /epPos/ posv     ! input
+      record /epPos/ posc     ! output
 
       call ep_sqtcclCnst(comp)
-      if( comp%struc  == 'sqtccl' .or.
-     *    comp%struc  == 'sqtccl_w') then
+      if( comp.struc  == 'sqtccl' ) then
          posc = posv
-      elseif( comp%struc(1:8)  == 'sqtccl_z' ) then
+      elseif( comp.struc  == 'sqtccl_z' ) then
          posc = posv
-      elseif( comp%struc(1:8)  == 'sqtccl_y' ) then
-         posc = epPos( posv%x, -posv%z, posv%y)
-      elseif( comp%struc(1:8)  == 'sqtccl_x' ) then
-         posc = epPos( -posv%z, posv%y, posv%x)
+      elseif( comp.struc  == 'sqtccl_y' ) then
+         posc = epPos( posv.x, -posv.z, posv.y)
+      elseif( comp.struc  == 'sqtccl_x' ) then
+         posc = epPos( -posv.z, posv.y, posv.x)
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epbsqtccl is invalid'
          stop
       endif
@@ -1097,23 +1105,22 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  posc     ! input
-       type(epPos)::  posv     ! output
+      record /Component/ comp  ! input.   component.
+      record /epPos/ posc     ! input
+      record /epPos/ posv     ! output
 
       call ep_sqtcclCnst(comp)
 !           (X,Y,Z)--->(x,y,z)
-      if( comp%struc  == 'sqtccl' .or.
-     *    comp%struc  == 'sqtccl_w' ) then
+      if( comp.struc  == 'sqtccl' ) then
          posv = posc
-      elseif( comp%struc(1:8)  == 'sqtccl_z' ) then
+      elseif( comp.struc  == 'sqtccl_z' ) then
          posv = posc
-      elseif( comp%struc(1:8)  == 'sqtccl_y' ) then
-         posv = epPos( posc%x, posc%z,  -posc%y)
-      elseif( comp%struc(1:8)  == 'sqtccl_x' ) then
-         posv = epPos( posc%z, posc%y, -posc%x)
+      elseif( comp.struc  == 'sqtccl_y' ) then
+         posv = epPos( posc.x, posc.z,  -posc.y)
+      elseif( comp.struc  == 'sqtccl_x' ) then
+         posv = epPos( posc.z, posc.y, -posc.x)
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epbsqtccl is invalid'
          stop
       endif
@@ -1125,23 +1132,22 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDirec.h"
-       type(Component)::  comp  ! input.   component.
-       type(epDirec)::  dirv     ! input
-       type(epDirec)::  dirc     ! output
+      record /Component/ comp  ! input.   component.
+      record /epDirec/ dirv     ! input
+      record /epDirec/ dirc     ! output
 
       call ep_sqtcclCnst(comp)
 
-      if( comp%struc  == 'sqtccl' .or. 
-     *    comp%struc  == 'sqtccl_w' ) then
+      if( comp.struc  == 'sqtccl' ) then
          dirc = dirv
-      elseif( comp%struc(1:8)  == 'sqtccl_z' ) then
+      elseif( comp.struc  == 'sqtccl_z' ) then
          dirc = dirv
-      elseif( comp%struc(1:8)  == 'sqtccl_y' ) then
-         dirc = epDirec( dirv%x, -dirv%z, dirv%y)
-      elseif( comp%struc(1:8)  == 'sqtccl_x' ) then
-         dirc = epDirec( -dirv%z,dirv%y, dirv%x)
+      elseif( comp.struc  == 'sqtccl_y' ) then
+         dirc = epDirec( dirv.x, -dirv.z, dirv.y)
+      elseif( comp.struc  == 'sqtccl_x' ) then
+         dirc = epDirec( -dirv.z,dirv.y, dirv.x)
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epbsqtccl is invalid'
          stop
       endif
@@ -1153,23 +1159,22 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDirec.h"
-       type(Component)::  comp  ! input.   component.
-       type(epDirec)::  dirc     ! input
-       type(epDirec)::  dirv     ! output
+      record /Component/ comp  ! input.   component.
+      record /epDirec/ dirc     ! input
+      record /epDirec/ dirv     ! output
 
       call ep_sqtcclCnst(comp)
 !           (X,Y,Z)<---(x,y,z)
-      if( comp%struc  == 'sqtccl' .or.
-     *    comp%struc  == 'sqtccl_w' ) then
+      if( comp.struc  == 'sqtccl' ) then
          dirv = dirc
-      elseif( comp%struc(1:8)  == 'sqtccl_z' ) then
+      elseif( comp.struc  == 'sqtccl' ) then
          dirv = dirc
-      elseif( comp%struc(1:8)  == 'sqtccl_y' ) then
-         dirv = epDirec( dirc%x, dirc%z,  -dirc%y)
-      elseif( comp%struc(1:8)  == 'sqtccl_x' ) then
-         dirv = epDirec( dirc%z, dirc%y, -dirc%x)
+      elseif( comp.struc  == 'sqtccl_y' ) then
+         dirv = epDirec( dirc.x, dirc.z,  -dirc.y)
+      elseif( comp.struc  == 'sqtccl_x' ) then
+         dirv = epDirec( dirc.z, dirc.y, -dirc.x)
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epbsqtccl is invalid'
          stop
       endif
