@@ -28,7 +28,7 @@
                       !       in unit of g/cm2. (minimum is not necessary
                       !       minumum. It difficult to say it for, eg
                       !       prism.
-       type(epmedia)::  media  ! input.  media of the component.
+      record /epmedia/ media  ! input.  media of the component.
                       ! some vales for interest may be
                       ! media.X0  : r.l in cm
                       ! media.X0g :  //    in g/cm2
@@ -45,12 +45,12 @@
 !            set min between 10 keV to 100 keV.
          EminG = min( max(sqrt(gramage)*30.e-6, 10.e-6), 100.e-6)
          EminE = EminG + masele
-         Recoilmin = max(EminG, 10.0*media%Z2*1.d-9)  ! For thin Pb,W
+         Recoilmin = max(EminG, 10.0*media.Z2*1.d-9)  ! For thin Pb,W
                                                  ! maybe some problems
       elseif( AutoEmin <= 3 ) then   ! 
          EminG = min( max(sqrt(gramage)*30.e-6, 10.e-6), 100.e-6)
          EminE = EminG + masele
-         Recoilmin = max(EminG,  10.0*media%Z2*1.d-9)
+         Recoilmin = max(EminG,  10.0*media.Z2*1.d-9)
     !--------------------------
       else
          write(0,*) ' AutoEmin=',AutoEmin, 
