@@ -204,7 +204,6 @@ c       Nevrun = Nevrun + 1     ! <= 9.05
        SumDe = 0.
        Move.Abort = 0     !  if this become non zero for an event, 
                      !  the particle is discarded or event is discarded
-c                 user dependent init
        call epcEloss  ! clear Eloss counters
 c>>>>>>>>>>>>>>>Light
        if(Light > 0) then
@@ -214,12 +213,11 @@ c>>>>>>>>>>>>>>>Light
           endif
        endif
 c<<<<<<<<<<<<<<<<<
+c                 user dependent init
        call ui1ev
 c               next call sets to icon=1,    if usetip is not
 c               user made.
        call usetip(icon)
-
-
 c                 icon=0-->user routine already set prtcl
 c                 icon=1-->no user routine for incident
        if(Trace) then
@@ -2111,12 +2109,20 @@ c                 or decay  is determined in cinteMuon;
       if(FirstC) then
          if(Incident.p.code .eq. kelec
      *        .or. Incident.p.code .eq. kphoton ) then
-            FirstInt = cTrack.pos
-            Proc1 = Move.proc
-            FirstC=.false.
+            if( cTrack.inciflag == 1 ) then
+!            if( cTrack.p.code == Incident.p.code 
+!     *        .and. cTrack.p.charge  == Incident.p.charge ) then
+               FirstInt = cTrack.pos
+               FirstIntTrack =cTrack
+               Proc1 = Move.proc
+               FirstC=.false.
+            endif
          elseif(Move.proc .eq. 'coll' .or.
      *           Move.proc .eq. 'decay') then
             if(Move.proc == 'coll') then
+                ! in jam we should introduce 'elas' for proc
+                ! in future, for elastic scattering and avoid
+                ! next 
                if(ActiveMdl == 'jam') then
 c                            if hadron proj, inela could be 0 or 1
                   call cjamElaInfo(1, inela)
@@ -2126,9 +2132,15 @@ c                            if hadron proj, inela could be 0 or 1
             else
                inela = 1
             endif
-            if(inela == 1 ) then
+            if( inela == 1 
+!           next is added v9.161; photo hadron->pion col. may come
+     *          .and. cTrack.inciflag == 1 ) then
+!     *           .and. cTrack.p.code == Incident.p.code 
+!     *           .and. cTrack.p.subcode == Incident.p.subcode 
+!     *           .and. cTrack.p.charge  == Incident.p.charge ) then
 c                   ielastic/decay so  regard as 1st interaction   
                FirstInt = cTrack.pos
+               FirstIntTrack = cTrack
                Proc1 = Move.proc
                call epsaveFirstCol
                FirstC=.false.
@@ -2137,15 +2149,24 @@ c                   ielastic/decay so  regard as 1st interaction
      *         (  Move.proc .eq. 'pair' .or.
      *           Move.proc .eq. 'brem' .or.
      *           Move.proc .eq. 'nuci' ) ) then
-            FirstInt = cTrack.pos
-            Proc1 = Move.proc
-            FirstC=.false.
+            if( cTrack.inciflag == 1 ) then
+!            if( cTrack.p.code == Incident.p.code 
+!     *        .and. cTrack.p.charge  == Incident.p.charge ) then
+               FirstInt = cTrack.pos
+               FirstIntTrack =cTrack
+               Proc1 = Move.proc
+               FirstC=.false.
+            endif
          endif
          if(.not. FirstC) then
 !            the interaction was recognized as the first one
-            call epl2w(cTrack.cn, FirstInt, temppos)
-            FirstInt = temppos
+!             convet vector into world coord.
+            call epl2wTrack(cTrack, FirstIntTrack)
+            FirstInt = FirstIntTrack.pos ! cp pos info. for compat
+!            call epl2w(cTrack.cn, FirstInt, temppos)
+!            FirstInt = temppos
             FirstMedia = Media(MediaNo)
+!            FirstIntTrack.pos = temppos
             firstCn = cTrack.cn
             if(Light == 21 ) then
                call epLightIOwrite1stCol
@@ -2163,6 +2184,19 @@ c                   ielastic/decay so  regard as 1st interaction
 
       icon = 1
       end
+      subroutine epl2wTrack(aTrack, bTrack)
+!        convert local info (pos, w, p) into world ones
+      implicit none
+#include  "ZepTrack.h"
+
+      record /epTrack/ aTrack ! input
+      record /epTrack/ bTrack ! output.
+      bTrack = aTrack
+      call epl2w(aTrack.cn, aTrack.pos, bTrack.pos)      
+      call epl2wdm(aTrack.cn, aTrack.w, bTrack.w, bTrack.p)
+      end    subroutine epl2wTrack
+
+
       subroutine epcpTargetInfo    
 !       copy target info in xmedia to Epics Media
       use modXsecMedia, only: TargetNucleonNo, TargetProtonNo,
