@@ -236,6 +236,14 @@ c     **************  inquire the first collision point
       record /epPos/ firstpos  ! output.
       firstpos = FirstInt
       end
+c     **************  inquire the first collision  track info.
+      subroutine epq1stIntTrack(firstTrack)
+      implicit none
+#include "ZepTrackv.h"
+      record /epTrack/ firstTrack ! output.
+      firstTrack = FirstIntTrack
+      end
+
 c     **************  inquire the comp. # where the first collision  (decay)
 c                  etc occurred.   
       subroutine epqFirstICN(compno)
